@@ -7,7 +7,7 @@ from core.tboard    import save_scalar, draw_graph
 from core.losses    import custom_rmse, custom_bce
 from core.metrics   import custom_acc
 from core.encoder   import Encoder
-from core.utils     import load_model
+from core.utils     import load_weights
 from tensorflow.keras.layers import Input, Dense
 from tensorflow.keras.optimizers import Adam
 from tensorflow.keras import Model
@@ -26,7 +26,7 @@ def get_ASTROMER(num_layers=2,
                  no_train=True,
                  maxlen=100,
                  batch_size=None,
-                 load_weights=False):
+                 pretrained_weights=False):
 
     serie  = Input(shape=(maxlen, 1),
                   batch_size=None,
@@ -66,7 +66,7 @@ def get_ASTROMER(num_layers=2,
                  outputs=x,
                  name="ASTROMER")
 
-    if load_weights:
+    if pretrained_weights:
         model = load_weights(model, git_link="https://github.com/HarshVardhanGoyal/test_model.git", model_name="astromer_10022021")
         
     return 
